/*
 ******************************************************************************
 *
 * @file     charger_module.c
 * @brief    charger module
 *                 
 *
 * @version  1.0
 * @date     2022/07/12   17:35:40
 * @author   Alex Xu
 *
 * Copyright (c) 2013-2099,Tkplusemi Technology Co.,Ltd.
 * All Rights Reserved
 *
 * History:
 * Revision          Date           Author            Desc
 * 1.0.0            2022/07/12      Alex          build this file
 ******************************************************************************
 */
/*_____ I N C L U D E S ____________________________________________________*/
#include "charger_module.h"
#include "adc.h"
#include "sys_tim.h"
#include "discharge_module.h"
#include "system.h"
#include "vox_module.h"
#include "led.h"

bit Charger_Done = 0;

#if CHARGER_ENABLE
/******************************************************************************\
                          Macro definitions
\******************************************************************************/
#define NTC_PRO_DEBOUNCE_TIM	10

/******************************************************************************\
                             Variables definitions
\******************************************************************************/

//idata TE_CHG_STA ChgStatus; 	// ϵͳ״̬


//bit NTC_Low_Pro_Flag = 0;
//bit NTC_High_Pro_Flag = 0;
//bit NTC_CHG_02C_Flag = 0;
//bit NTC_CHG_1C_Flag = 0;


/******************************************************************************\             
                             Functions definitions
\******************************************************************************/

/*
 *******************************************************************************
 *             void Charger_init(void)
 *
 * Description : Charger Initialization
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
 #if 0
void Charger_Init(void)
{
	SFRADDR = PMU_CTL1;
	SFRDATA |= 0x07;			//صѹ enable źţصѹ⵵λѡ3.3V		
	/* Setting CV */
	REG_CHG2 = 0x00;    //0:4.20V;1:4.35V
	/* Setting CHG Current */
	REG_CHG1 = 0x03;		//000:100mA;001:200mA;010:250mA;011:300mA;100:350mA;101:400mA;110:450mA;111:500mA
	
}
#endif

/*
 *******************************************************************************
 *             void Charger_Current_Set(void)
 *
 * Description : Charger Initialization
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
 #if 0
void Charger_Current_Set(void)
{
	uint16_t Charger_CurADC_Value = 0;
	/* ͨⲿADC1ֵóֵ */
	Charger_CurADC_Value = ADC_Chn_Value(ADC_CH1);	

	
	/* Setting CV */
	REG_CHG2 = 0x00;    //0:4.20V;1:4.35V
	/* Setting CHG Current */
	REG_CHG1 = 0x03;		//000:100mA;001:200mA;010:250mA;011:300mA;100:350mA;101:400mA;110:450mA;111:500mA
	
}
#endif

/*
 *******************************************************************************
 *             uint8_t Charger_NTC_Control(uint8_t Charge_sta)
 *
 * Description : Charger NTC Control
 * NTC ֧ 103  104 裬NTC ¶ȼͨ ADC ɼ NTC ŵѹ
 * ֵ֧¶ȼԻֵ֧Ʒ 103  NTC Ҫһ 8.2k 
 
 * 裨20uA 103 NTC Ҫ 10k 裩104  NTC  82k 衣
 * ʹܳǰȼNTC ¶ȣ NTC գ NTC ܣ
 *  NTC  0Vرճͷŵ硣NTC رճ磬
 * ¶Ȼָ 100msټ硣
 *
 * Arguments   : NTC_Protect_Type_e NTC_Type:Shield JEITA or IEC;Charge_sta:Charge or not

 * Returns     :NTC_Flag (0:Shield;		1:JEITA;	2:IEC)

 * Notes       : NONE
 *
 *******************************************************************************
 */
#if NTC_ENABLE
uint8_t PMU_NTC_Control(void)
{
	uint16_t NTC_Adc = 0;	
	uint8_t nNTC_Pro_Flag = 0;
	
	static bit NTC_Low_Pro_Flag;
	static bit NTC_High_Pro_Flag;
	
#if NTC_ENABLE	

	NTC_Adc = ADC_NTC_Value();

#endif

	if(NTC_Adc >= 2000)		////NTCܣNTCգ NTC ܣ
	{
		return 1;
	}

	if(NTC_Adc <= T_0C && NTC_Adc > T_45C)		//NTC
	{
		if(NTC_Low_Pro_Flag)
		{
			if( NTC_Adc < T_3C )
			{
				NTC_Low_Pro_Flag = 0;
				nNTC_Pro_Flag = 0;
			}
			else
			{
				nNTC_Pro_Flag = 1;
			}
		}
					
		if(NTC_High_Pro_Flag)
		{
			if( NTC_Adc > T_42C )
			{
				NTC_High_Pro_Flag = 0;
				nNTC_Pro_Flag = 0;
			}
			else
			{
				nNTC_Pro_Flag = 1;
			}
		}		
	}
	else			//쳣
	{					
			
		if(NTC_Adc > T_0C)
		{
			NTC_Low_Pro_Flag = 1;
		}
		else
		if(NTC_Adc < T_45C)
		{
			NTC_High_Pro_Flag = 1;
		}
																	
		nNTC_Pro_Flag = 1;		
	}

	return nNTC_Pro_Flag;	
}
#endif
/*
 *******************************************************************************
 *             void Charger_Handler(void)
 *
 * Description : Charger Handle. ---- ̳˸ NTC ̬ڳͽֹѹ⣬Ӳơ
				쳣ӲӦͱ־λԽӦ
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
 /*
1糬ʱ糬ʱرճʹܣȴVINγ
*/
void Charger_Handler(void)
{	
	if( !(CHIP_STA4 & 0x80) )				//δ⵽Power good,رChargerʹܺ󷵻ء
	{
		CHG_CTL &= ~0x01;					//Disable Charger	
		IRQ_FLAG9 = 0x10;					//δ磬Charg complete interruptж
		Charger_Done = 0;
		return;
	}	
	
	/*ֻ糬ʱʱҪVBUS²κ¿ʼCharger̡*/
	if ( IRQ_FLAG9 & 0x0C )			//糬ʱ,Tricle charg and Fast charge timeout
	{
		CHG_CTL &= ~0x01;					//Disable Charger	
		if ( IRQ_FLAG10 & 0xC0 )    //Plugin\Plugout interrupt
		{
			IRQ_FLAG9 = 0x0C;
			IRQ_FLAG10 = 0xC0;		//Clear Plugin\Plugout interrupt
		}
		return;
	}
	else					/*δʱPlugPlugin\Plugout int*/
	{
		if( IRQ_FLAG10 & 0xC0 )
		{
			IRQ_FLAG10 = 0xC0;		//Clear Plugin\Plugout interrupt
		}
	}
	
#if NTC_ENABLE	
	/*NTC Handle*/	 				//ʹChargerǰȼNTC¶ȣ쳣Ͳ硣(CHIP_STA4 & 0x80):PG
	if( PMU_NTC_Control() )						//NTC硣
	{		
		CHG_CTL &= ~0x01;	//Disable Charger.
		return;
	}
#endif

	if( IRQ_FLAG9 & 0x10 )			//Charg complete interrupt
	{
#if ADC_ENABLE
		
#ifdef _DEBUG_CHARGER					
		printf("Chg Done\r\n");
#endif	
		if( Vbat_Adc < BAT_RECHARG )
		{
			//CHG_CTL |= 0x01;				//Enable Charger
			IRQ_FLAG9 = 0x10;		
#ifdef _DEBUG_CHARGER					
			printf("En Chg\r\n");
#endif						
		}
		else
		{
			CHG_CTL &= ~0x01;				//Disable Charger
#ifdef _DEBUG_CHARGER					
			printf("Dis Chg\r\n");
#endif						
		}
		Charger_Done = 1;
		
#endif
	}
	else
	{
		CHG_CTL |= 0x01;					//Enable Charger	
		Charger_Done = 0;
	}
}

#endif

