/*
 ******************************************************************************
 *
 * @file     system.c
 * @brief    system module
 *                 
 *
 * @version  1.0
 * @date     2022/08/04   15:00:40
 * @author   Alex Xu
 *
 * Copyright (c) 2013-2099,Tkplusemi Technology Co.,Ltd.
 * All Rights Reserved
 *
 * History:
 * Revision          Date           Author            Desc
 * 1.0.0            2022/08/15      Alex          build this file
 * Attention:1ͬһByteжϱ־λڲͬжУжϱ־λд1壩 |= Ҫ = 
 			磺IRQ_FLAG10 = 0x02;	//Clear bit0,bit1 interrupt flag
 			 2ⲿж0Ҫϵͳѹܣжϴ߼ܴԤӿڣ
 ******************************************************************************/
 /*_____ I N C L U D E S ____________________________________________________*/

#include "system.h"
#include "gpio.h"
#include "adc.h"
#include "hall.h"
#include "key.h"
#include "sleep.h"
#include "uart.h"
#include "bat.h"
#include "sys_tim.h"
#include "charger_module.h"
#include "discharge_module.h"
#include "led.h"
#include "vox_module.h"
#include "watchdog.h"
#include "userapp.h"

/******************************************************************************\
                          Macro definitions
\******************************************************************************/

/******************************************************************************\
                             Variables definitions
\******************************************************************************/

/******************************************************************************\
                             Functions definitions
\******************************************************************************/


/*
 *******************************************************************************
 *             void System_Init(void)
 *
 * Description : System Initialization
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
void System_Init(void)
{
	SFRADDR = PMU_CTL0; 			//оƬӲ󣬹̶ 
	SFRDATA |= 0x30;	

	/*test*/
	SFRADDR = P0_PD;	
	SFRDATA &= ~0x03;
	
#if UART0_ENABLE	

//	SFRADDR = P0_PU;
//	SFRDATA = 0x02;

//    SFRADDR = MFP_CTL0;
//    SFRDATA = 0x05;    		//P01 as UART's TX,P00 as UART's RX
    
    BD = 1;              //Select additional Baudrate generator
    PCON |= 0x80;        //Baudrate double enable
    
    //baudrate set
    S0RELH = HIBYTE(S0REL_VALUE);
    S0RELL = LOBYTE(S0REL_VALUE);//s0rel=1023, baudrate = fclk/32 = 187.5k

	S0CON = 0x40;		//SCON: MODE 1, 8-bit UART, REN disable
	 
    TI0 = 1;  
    RI0 = 1;
	ES0 = 1;            //Enable UART0 IRQ  
	
#endif	

#if VOX_ENABLE		

	VOX_CTL0 = 0xC3;	   //VOX ؽ롢ʶʹܣԶʶ𡣴Vox vdsǯѹʹܣҪVOX 5V

	SFRADDR = VOX_CON0;    //VOX200mA
	SFRDATA &= ~0x1F;	
	SFRDATA |= (VOX_IOUT_200MA << 3) | VOX_ADT_Cur_4_5UA;

#endif

	TMOD = 0x01;	  //mode 1, 16bit timer

	TH0 = C_TIM0_Reload >> 8;
	TL0 = C_TIM0_Reload & 0xFF; 

	ET0 = 1;		//enable time0 interrupt
	TR0 = 1;		//time0 run

#if TIMER1_ENABLE	
	
	TMOD |= 0x10;     //mode 1, 16bit timer
	
    TH1 = C_TIM1_Reload >> 8;
    TL1 = C_TIM1_Reload & 0xFF; 
 	
    ET1 = 1;        //enable time1 interrupt
    TR1 = 1;        //time1 run	
    
#endif

	/*GPIO Set*/
	SFRADDR = P0_OE;
	SFRDATA = 0x1C; 		//COM_CTRL(P02)LED1(P03)LED2(P04)ΪGPIO

#ifdef LED_DISPLAY
	
	SFRADDR = P0_DRV;		//P03P04Ϊ400
	SFRDATA = 0x3C; 

	pin_LED_1 = 0;
	pin_LED_2 = 0;
	
#endif

#if WTG_ENABLE  
	/* 65ms */
	WDTREL = 0x00;      //WDTPS = 0,wdt_f = wdt_f1/2;WDTPS = 1,wdt_f = wdt_f1/32;
	/* 1s */
//	WDTREL = 0x80;      //WDTPS = 0,wdt_f = wdt_f1/2;WDTPS = 1,wdt_f = wdt_f1/32;
#endif

#if ADC_ENABLE

	SFRADDR = MFP_CTL1;		//Set P07 Pinmux As AD4 Function
	SFRDATA |= 0x80;
	
	SFRADDR = ADCCS_CTL0;				//AD0~AD4 GPIO constant 20uA current source enable.
	SFRDATA = 0x10;
	
#endif	

	/* Interrupt Enable ӦѡҪж */	
	SFRADDR = IRQ_EN3;		//INT2 --- VOX EDGE LOADON
	SFRDATA = 0x3C;	

	//SFRADDR = IRQ_EN10;		//INT4 --- Hall interrupt enable.
	//SFRDATA = 0x0C;
	
	/* ⲿжʹ */
	EX0 = 1;
	EX2 = 1;	
	//EX4 = 1;	
	
	EAL = 1;	//жϡ		

	IRQ_FLAG9 = 0x1C;   	// Charge complete IntTricle/Fast Charge Time expire Int	
	IRQ_FLAG10 = 0xC0;		// VBUS Plugin\Plugout Int
	IRQ_FLAG0 = 0x0C;		//Vox·

#if CHARGER_ENABLE

#ifdef SY8836					//ϷоƬرVBUS OVʹ
	SFRADDR = PMU_CTL7;				
	SFRDATA &= ~0x20;

	SFRADDR = REG_CHG0;
	SFRDATA |= 0x04;		//VDPM 
#endif	

	CHG_CTL |= 0x10;				//糬ʱʹ

//	REG_CHG1 = CHG_CURRENT_400MA;		//400mA

	//REG_CHG2 = 0x01;		//CVѹ4.35V

#endif
	
}

/*
 *******************************************************************************
 *             void EX0_isr(void ) interrupt Interrupt_Vector_IE0
 *
 * Description : System External Intterupt 0
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
void EX0_isr(void) interrupt Interrupt_Vector_IE0
{

}

/*
 *******************************************************************************
 *             void EX2_isr(void) interrupt Interrupt_Vector_IE2
 *
 * Description : System External Intterupt 2 
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */

void EX2_isr(void) interrupt Interrupt_Vector_IE2
{
	IRQ_FLAG3 = 0x3C;
	
#if SLEEP_ENABLE		
//	if( !Enter_Sleep_Cnt_Restart_Flag )
	{
		Enter_Sleep_Cnt_Restart_Flag = 1;
	}
#endif
}

/*
 *******************************************************************************
 *              void EX4_isr(void) interrupt Interrupt_Vector_IE4
 *
 * Description : System External Intterupt 4 
 *
 * Arguments   : NONE

 * Returns     : NONE

 * Notes       : NONE
 *
 *******************************************************************************
 */
 #if 0
 void EX4_isr(void) interrupt Interrupt_Vector_IE4
{	

	IRQ_FLAG10 = 0x0C;

#if SLEEP_ENABLE	

	//if( !Enter_Sleep_Cnt_Restart_Flag )
	{
		Enter_Sleep_Cnt_Restart_Flag = 1;
	}
	
#endif
}
#endif
